==> nextcloud-14.0.4.tar.bz2: nextcloud/apps/dav/l10n/es.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Todos",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} creó el calendario {calendar}",
    "You created calendar {calendar}" : "Usted creó el calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} eliminó el calendario {calendar}",
    "You deleted calendar {calendar}" : "Usted eliminó el calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizó el calendario {calendar}",
    "You updated calendar {calendar}" : "Usted actualizó el calendario {calendar}",
    "You shared calendar {calendar} as public link" : "Has compartido el calendario {calendar} con un enlace público",
    "You removed public link for calendar {calendar}" : "Has eliminado el enlace público al calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} compartió el calendario {calendar} con usted",
    "You shared calendar {calendar} with {user}" : "Usted compartió el calendario {calendar} con {usuario}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartió el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} dejó de compartir el calendario {calendar} con usted",
    "You unshared calendar {calendar} from {user}" : "Usted dejó de compartir el calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} dejó de compartir el calendario {calendar} del usuario{user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} dejó de compartir su propio calendario {calendar}",
    "You shared calendar {calendar} with group {group}" : "Usted compartió el calendario {calendar} con el grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartió el calendario {calendar} con el grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Usted dejó de compartir el calendario {calendar} del grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} dejó de compartir el calendario {calendar} del grupo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creó el evento {event} en el calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Usted creó el evento {event} en el calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eliminó el evento {event} del calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Usted eliminó el evento {event} del calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizó el evento {event} en el calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Usted actualizó el evento {event} en el calendario {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creó la tarea {todo} en la lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Usted creó la tarea {todo} en la lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} eliminó la tarea {todo} de la lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Usted eliminó la tarea {tod} de la lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualizó la tarea {todo }en la lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Usted actualizó la tarea {todo} en la lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} completó la tarea {todo} en la lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Usted completó la tarea {todo} en la lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabrió la tarea {todo} en la lista {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Usted reabrió la tarea {todo} en la lista {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> fue modificado.",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> del calendario fue modificado.",
    "A calendar <strong>todo</strong> was modified" : "Una <strong>lista de tareas</strong> fue modificada",
    "Contact birthdays" : "Cumpleaños del contacto",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "Invitation canceled" : "Invitación cancelada",
    "Hello %s," : "Hola, %s:",
    "The meeting »%1$s« with %2$s was canceled." : "La reunión »%1$s« con %2$s se ha cancelado.",
    "Invitation updated" : "Invitación actualizada",
    "The meeting »%1$s« with %2$s was updated." : "La reunión »%1$s« con %2$s se ha actualizado.",
    "%1$s invited you to »%2$s«" : "%1$s te ha invitado a »%2$s«",
    "When:" : "Cuándo:",
    "Where:" : "Dónde:",
    "Description:" : "Descripción:",
    "Link:" : "Enlace:",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "More options …" : "Más opciones...",
    "More options at %s" : "Más opciones en %s",
    "Contacts" : "Contactos",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Extremo de WebDAV",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección remota: %s",
    "Request ID: %s" : "ID de solicitud: %s",
    "There was an error updating your attendance status." : "Ha habido un error al actualizar tu estado de asistencia.",
    "Please contact the organizer directly." : "Por favor, contacta directamente con el organizador.",
    "Are you accepting the invitation?" : "¿Aceptas la invitación?",
    "Tentative" : "Provisional",
    "Save" : "Guardar",
    "Your attendance was updated successfully." : "Tu asistencia se ha actualizado con éxito.",
    "Calendar server" : "Servidor de calendario",
    "Send invitations to attendees" : "Enviar invitaciones a los asistentes",
    "Please make sure to properly set up the email settings above." : "Por favor, asegúrate de que las configuraciones de correo de arriba son correctas",
    "Automatically generate a birthday calendar" : "Generar automáticamente un calendario de cumpleaños",
    "Birthday calendars will be generated by a background job." : "Los calendarios de cumpleaños se generarán mediante un trabajo en segundo plano.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Por ello, no estarán disponibles inmediatamente tras activarlos, sino que aparecerán después de cierto tiempo.",
    "%s via %s" : "%s vía %s",
    "The meeting »%s« with %s was canceled." : "La reunión »%s« con %s se ha cancelado.",
    "The meeting »%s« with %s was updated." : "La reunión »%s« con %s se ha actualizado.",
    "%s invited you to »%s«" : "%s te ha invitado a »%s«",
    "CalDAV server" : "Servidor CalDAV"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.2.tar.bz2: nextcloud/apps/dav/l10n/es.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Todos",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} creó el calendario {calendar}",
    "You created calendar {calendar}" : "Usted creó el calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} eliminó el calendario {calendar}",
    "You deleted calendar {calendar}" : "Usted eliminó el calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizó el calendario {calendar}",
    "You updated calendar {calendar}" : "Usted actualizó el calendario {calendar}",
    "You shared calendar {calendar} as public link" : "Has compartido el calendario {calendar} con un enlace público",
    "You removed public link for calendar {calendar}" : "Has eliminado el enlace público al calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} compartió el calendario {calendar} con usted",
    "You shared calendar {calendar} with {user}" : "Usted compartió el calendario {calendar} con {usuario}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartió el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} dejó de compartir el calendario {calendar} con usted",
    "You unshared calendar {calendar} from {user}" : "Usted dejó de compartir el calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} dejó de compartir el calendario {calendar} del usuario{user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} dejó de compartir su propio calendario {calendar}",
    "You shared calendar {calendar} with group {group}" : "Usted compartió el calendario {calendar} con el grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartió el calendario {calendar} con el grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Usted dejó de compartir el calendario {calendar} del grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} dejó de compartir el calendario {calendar} del grupo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creó el evento {event} en el calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Usted creó el evento {event} en el calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eliminó el evento {event} del calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Usted eliminó el evento {event} del calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizó el evento {event} en el calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Usted actualizó el evento {event} en el calendario {calendar}",
    "Busy" : "Ocupado",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creó la tarea {todo} en la lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Usted creó la tarea {todo} en la lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} eliminó la tarea {todo} de la lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Usted eliminó la tarea {tod} de la lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualizó la tarea {todo }en la lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Usted actualizó la tarea {todo} en la lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} completó la tarea {todo} en la lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Usted completó la tarea {todo} en la lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabrió la tarea {todo} en la lista {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Usted reabrió la tarea {todo} en la lista {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> fue modificado.",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> del calendario fue modificado.",
    "A calendar <strong>todo</strong> was modified" : "Una <strong>lista de tareas</strong> fue modificada",
    "Death of %s" : "Muerte de %s",
    "Contact birthdays" : "Cumpleaños del contacto",
    "Calendar:" : "Calendario:",
    "Date:" : "Fecha:",
    "Where:" : "Dónde:",
    "Description:" : "Descripción:",
    "Untitled event" : "Evento sin título",
    "_%n year_::_%n years_" : ["%n año","%naños"],
    "_%n month_::_%n months_" : ["%n mes","%n meses"],
    "_%n day_::_%n days_" : ["%n día","%n días"],
    "_%n hour_::_%n hours_" : ["%n hora","%n horas"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos"],
    "%s (in %s)" : "%s (en %s)",
    "%s (%s ago)" : "%s (hace %s)",
    "Calendar: %s" : "Calendario: %s",
    "Date: %s" : "Fecha: %s",
    "Description: %s" : "Descripción: %s",
    "Where: %s" : "Lugar: %s",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "Invitation canceled" : "Invitación cancelada",
    "Hello %s," : "Hola, %s:",
    "The meeting »%1$s« with %2$s was canceled." : "La reunión »%1$s« con %2$s se ha cancelado.",
    "Invitation updated" : "Invitación actualizada",
    "The meeting »%1$s« with %2$s was updated." : "La reunión »%1$s« con %2$s se ha actualizado.",
    "%1$s invited you to »%2$s«" : "%1$s te ha invitado a »%2$s«",
    "When:" : "Cuándo:",
    "Link:" : "Enlace:",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "More options …" : "Más opciones...",
    "More options at %s" : "Más opciones en %s",
    "Contacts" : "Contactos",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Tu %s necesita configurarse para usar HTTPS en caso de usar CalDAV y CardDAV con iOS/macOS.",
    "Configures a CalDAV account" : "Configura una cuenta CalDAV",
    "Configures a CardDAV account" : "Configura una cuenta CardDAV",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Extremo de WebDAV",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección remota: %s",
    "Request ID: %s" : "ID de solicitud: %s",
    "There was an error updating your attendance status." : "Ha habido un error al actualizar tu estado de asistencia.",
    "Please contact the organizer directly." : "Por favor, contacta directamente con el organizador.",
    "Are you accepting the invitation?" : "¿Aceptas la invitación?",
    "Tentative" : "Provisional",
    "Save" : "Guardar",
    "Your attendance was updated successfully." : "Tu asistencia se ha actualizado con éxito.",
    "Calendar server" : "Servidor de calendario",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instala también la {calendarappstoreopen}app de Calendario{linkclose} o {calendardocopen}conecta tu escritorio y móvil para sincronizar ↗{linkclose}.",
    "Send invitations to attendees" : "Enviar invitaciones a los asistentes",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Por favor, asegúrate de configurar correctamente {emailopen}el servidor web{linkclose}",
    "Automatically generate a birthday calendar" : "Generar automáticamente un calendario de cumpleaños",
    "Birthday calendars will be generated by a background job." : "Los calendarios de cumpleaños se generarán mediante un trabajo en segundo plano.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Por ello, no estarán disponibles inmediatamente tras activarlos, sino que aparecerán después de cierto tiempo.",
    "Send notifications for events" : "Enviar notificaciones de los eventos",
    "Notifications are sent via background jobs, so these must occur often enough." : "Las notificaciones son enviadas a través de trabajos en segundo plano, por lo que estos deben ocurrir con la suficiente frecuencia.",
    "Enable notifications for events via push" : "Activar notificaciones push para eventos",
    "Please make sure to properly set up the email settings above." : "Por favor, asegúrate de que las configuraciones de correo de arriba son correctas",
    "Notifications will be send through background jobs, so these need to happen often enough." : "Las notificaciones se enviarán a través de trabajos en segundo plano, por lo que estos deben llevarse a cabo con cierta frecuencia."
},
"nplurals=2; plural=(n != 1);");
